@@ -32,6 +32,11 @@ def GP_PlateData(FileName, GrowthThresh=3, GVcorrect={'GVexp':1, 'eexp':0}, GPso
         skiprows = 23
         decimal = ','
         TimeUnit = 60
+    elif GPsource == 'clean':
+        skiprows = 0
+        decimal = '.'
+        TimeUnit = 60
+        
     GVexp = GVcorrect['GVexp']
     eexp = GVcorrect['eexp']
 
