@@ -79,9 +79,12 @@ def FitGrowth(time, ydat, law='lin', inlog=False, p0=None):
         y_lim = None
     elif law == 'log':
         LogGrowth = lambda t, r, y0, K: y0*K / (y0 + (K-y0)*np.exp(-r*t))
-        popt, pcov = curve_fit(LogGrowth, time, ydat, p0=p0)
-        y_rate, y_init, y_lim = popt[0:3]
-        y_sterr = np.sqrt(np.diag(pcov))[0]
+        try:
+            popt, pcov = curve_fit(LogGrowth, time, ydat, p0=p0)
+            y_rate, y_init, y_lim = popt[0:3]
+            y_sterr = np.sqrt(np.diag(pcov))[0]
+        except RuntimeError:
+            return False
     return y_rate, y_sterr, y_init, y_lim
 
 def FitR2(time, ydata, popt, law='lin', inlog=False):
@@ -149,7 +152,7 @@ def PlotFit(time, ydat, par, sterr, xyunits, law='lin', inlog=False, export_file
         ydat = np.log(ydat)
     plt.plot(time, ydat, 'gx', label='data', **kwargs)
     if law == 'lin':
-        func = lambda time, a, b: a*time+b 
+        func = lambda t, a, b: a*t + b
     elif law == 'exp':
         func = lambda t, r, y0: y0*np.exp(r*t)
     elif law == 'log':
@@ -163,4 +166,4 @@ def PlotFit(time, ydat, par, sterr, xyunits, law='lin', inlog=False, export_file
     plt.legend()
     if export_file:
         plt.savefig(export_file)
-    plt.show()
+    # plt.show()
